capture log close
log using mco18-brm-dc-distribution-2018-04-03, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  Distribution of effects

local pgm mco18-brm-dc-distribution-2018-04-03
local dte 2018-04-03
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

//  #1 lfp effect of wc

use binlfp4, clear

codebook lfp k5 k618 agecat wc hc lwg inc, compact
tab1 agecat, miss
logit lfp k5 k618 i.agecat i.wc i.hc lwg inc
estimates store logitmodel

//  #1.1 compute DCM and ADC

margins, dydx(wc) // AME
local adc = el(r(b),1,2) // add ADC(wc) to local

margins, dydx(wc) atmeans // MEM
local dcm = el(r(b),1,2) // add DCM(wc) to local

//  #1.2 save DCwc for each case

margins, dydx(wc) generate(DCwc)
codebook DCwc*, compact
label var DCwc2 "DC for wife attending college"
sum DCwc2

//  #1.3 histogram of effects

local graphname "effects-wc"
histogram DCwc2, xlab(0(.05).20) ylab(0(10)30, grid) ///
    percent bin(25) color(gs10) fcolor(gs12) ///
    /// add labels for ADC and DCM
    text(-1.5 `adc' "ADC", color(red*.8)  placement(center)) ///
    text(-1.5 `dcm' "DCM", color(blue*.8) placement(center)) ///
    text( 0   `adc' "|"  , color(red*.8)  placement(center)) ///
    text( 0   `dcm' "|"  , color(blue*.8) placement(center)) ///
    caption("`graphname' `tag'", size(*.5) pos(5) col(gs10)) 
    
graph export `pgm'-`graphname'.$graphfmt, replace

//  #2 diabetes effect of bmi 

use svyhrs4, clear
svyset secu [pweight=kwgtr], ///
    strata(stratum) vce(linearized) singleunit(missing)

drop if age<53 | race == 0 | race == 7
gen black = race
recode black 1=0 2=1
lab def black 0 "White" 1 "Black"
lab val black black
tab race black

drop if ///
    arthritis>=. | diabetes>=. | goodhlth>=. | age>=. | female>=. | ed4cat>=.

//  #2.1 fit model

nmlab diabetes age bmi female ed4cat black
svy: mean diabetes age bmi female black
svy: tab ed4cat
    
svy: logit diabetes c.bmi c.age##c.age i.female i.ed4cat i.black
est store svymodel

//  #2.2 DC bmi+5

mchange bmi, amount(sd) delta(5) decimal(8)

//  #2.3 save effects for each case

sum bmi
margins, at(bmi=gen(bmi)) at( bmi=gen(bmi+5)) gen(PRbmi) 
codebook PRbmi*, compact

//  create DC(bmi_ 

gen double DCbmi = PRbmi2 - PRbmi1
lab var DCbmi "DC for increase of 5 in bmi"
svy: mean DCbmi // verify this equals adc from mchange


//  #2.4 plot effects for each case

local graphname "effects-bmi"
hist DCbmi, percent fcol(black*.2) ylab(0(2)10) ///
    xline(.080, lcol(green*.6) lstyle(dash)) /// value of ADC
    xlabel(0(.02).14) xtitle("Discrete change for BMI + 5") ///
    scale(1.1) plotregion(margin(zero) lcol(white))

graph export `pgm'-`graphname'.$graphfmt, replace

//  #2.5 effects of BMI by race
    
local graphname "effects-bmi-race"
twoway ///
    (hist DCbmi if race == 1, percent fcol(none) bcol(red*.8)) ///
    (hist DCbmi if race == 2, percent fcol(none) bcol(blue*.8)), ///
    xlabel(0(.02).14) xtitle("Discrete change for BMI + 5") ///
    legend(symxsize(7) order(1 "White" 2 "Black") pos(12) ring(0) ) ///
    scale(1.1) plotregion(margin(zero) lcol(white))

graph export `pgm'-`graphname'.$graphfmt, replace
    
log close
exit

