capture log close
log using mco18-nonlin-2018-04-08, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  Nonlinearities on the right hand side

local pgm mco18-nonlin-2018-04-08
local dte 2018-04-08
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

//  graph options

global nogapnoline "plotregion(margin(zero) lcol(white)) "
global captionopt  "size(*.5) pos(5) col(gs10)"
global symdotplot  "mcol(blue*1.2)"
global lineprob    "msym(i) mcol(blue) lcol(blue) lpat(solid)  lwid(*1.4)"
global linepoly    "msym(i) mcol(blue) lcol(blue)  lpat(solid) lwid(*1.4)"
global M1line      "msym(i) lcol(red*1.2)   lpat(solid) lwid(*1.4)"
global M2line      "msym(i) lcol(green*1.2) lpat(dash)  lwid(*1.4)"
global M3line      "msym(i) lcol(blue*1.2)  lpat(shortdash) lwid(*1.4)"
global ylab        "ylab(0(.25)1, grid gmin gmax)"
global ylab5       "ylab(0(.1).5, grid gmax gmin)"
global ylab4       "ylab(0(.1).4, grid gmax gmin)"

// ===========================================================================
//  #1 set up analysis data

use svyhrs4, clear

drop if ///
    arthritis>=. | diabetes>=. | goodhlth>=. | age>=. | female>=. | ed4cat>=.
drop if age<53 // young ages were probably miscoded
sort age

svyset secu [pweight=kwgtr], ///
    strata(stratum) vce(linearized) singleunit(missing)

//  ==========================================================================
//  Descriptive

nmlab diabetes age female ed4cat
svy: mean diabetes arthritis age female goodhlth
svy: tab ed4cat

local graphname age-hist
histogram age, fcol(black*.4) lcol(black*.5) bin(25) ///
xtitle("Age") ///
scale(1.3) xsize(8) ysize(6.5) plotregion(margin(zero) lcol(white)) ///
xlabel(50(10)100) ///
    caption("`graphname' `tag'", $captionopt)
graph export `pgm'-`graphname'.$graphfmt, replace

    
//  ==========================================================================
//  #1 local polynomial smoothing

lpoly diabetes age if age<100, gen(d_age d_poly) nograph n(200) bwidth(5)
label var d_poly "Diabetes"
lpoly goodhlth age if age<100, gen(g_age g_poly) nograph n(200) bwidth(5)
label var g_poly "Good health"
lpoly arthritis age if age<100, gen(a_age a_poly) nograph n(200) bwidth(5)
label var a_poly "Arthritis"

global linea "msym(i) lcol(red)    lpat(longdash)  lwid(*1.4)" // arthritis
global lined "msym(i) lcol(green)  lpat(dash)      lwid(*1.4)" // diabetes
global lineg "msym(i) lcol(purple) lpat(shortdash) lwid(*1.4)" // good health

local graphname "combined-lpoly-prob"
graph twoway ///
   (connected a_poly a_age, $linea) /// 
   (connected d_poly d_age, $lined) /// 
   (connected g_poly g_age, $lineg) , ///
   xlab(50(10)100) xtitle(Age) ///
   $ylab yline(0 1, lcol(black)) ytitle(Pr(y|age)) ///
   legend(symxsize(6.9) size(*1.1) rows(1) region(lcolor(white))) ///
   $nogapnoline scale(1.2) ///
   caption("`graphname' `tag'", $captionopt) 
graph export `pgm'-`graphname'.$graphfmt, replace

//  ==========================================================================
//  #2 effect of ignoring nonlinearities

//  goodhlth

logit goodhlth age

mgen, at(age=(50(2.5)100)) stub(good) atmeans replace
label var goodpr1 "Logit on age"
label var g_poly "Polynomial smooth"

local graphname "goodhlth-lpoly-logit"
graph twoway ///
    (connected goodpr1 goodage, $lineprob) ///  $YAXgrid1
    (connected g_poly g_age, $lineg), ///
    xlab(50(10)100) xtitle(Age) ///
    yline(0 1, lcol(black)) $ylab ytitle(Pr(good health | age))  ///
    legend(symxsize(6.9) order(1 2) size(*1.1) region(lcolor(white))) ///
    $nogapnoline scale(1.2) ///
    caption("`graphname' `tag'", $captionopt) 
graph export `pgm'-`graphname'.$graphfmt, replace
    
//  arthritis

logit arthritis age

mgen, at(age=(50(2.5)100)) stub(arth) atmeans replace
label var arthpr1 "Logit on age"
label var a_poly "Polynomial smooth"

local graphname "arthritis-lpoly-logit"
graph twoway ///
    (connected arthpr1 arthage, $lineprob) ///  $YAXgrid1
    (connected a_poly a_age, $linea), ///
    xlab(50(10)100) xtitle(Age) ///
    yline(0 1, lcol(black)) $ylab ytitle(Pr(arthritis | age))  ///
    legend(symxsize(6.9) order(1 2) size(*1.1) region(lcolor(white))) ///
    $nogapnoline scale(1.2) ///
    caption("`graphname' `tag'", $captionopt) 
graph export `pgm'-`graphname'.$graphfmt, replace
    
//  diabetes

logit diabetes age

mgen, at(age=(50(2.5)100)) stub(diab) atmeans replace
label var diabpr1 "Logit on age"
label var d_poly "Polynomial smooth"

local graphname "diabetes-lpoly-logit"
graph twoway ///
    (connected diabpr1 diabage, $lineprob) ///
    (connected d_poly d_age, $lined), ///
    xlab(50(10)100) xtitle(Age) ///
    yline(0 1, lcol(black)) $ylab4 ytitle(Pr(diabetes | age))  ///
    legend(symxsize(6.9) order(1 2) size(*1.1) region(lcolor(white))) ///
    $nogapnoline scale(1.2) ///
    caption("`graphname' `tag'", $captionopt) 
graph export `pgm'-`graphname'.$graphfmt, replace

//  ==========================================================================
//  #3 diabetes

//  #3.1 fit models

svy: logit diabetes c.age i.female i.ed4cat, or
est store dMage1
test age

svy: logit diabetes c.age##c.age i.female i.ed4cat, or
est store dMage2
test c.age#c.age
test age c.age#c.age

svy: logit diabetes c.age c.age#c.age c.age#c.age#c.age i.female i.ed4cat
est store dMage3
test c.age#c.age#c.age
test c.age#c.age c.age#c.age#c.age
test age c.age#c.age c.age#c.age#c.age

estimates table dMage1 dMage2 dMage3, title(diabetes) ///
    eform b(%9.5f) p(%9.3f) 
    
//  3.2 fit without survey estimation in order to compare BICs & AICs

qui {
logit diabetes age i.female i.ed4cat
est store nosvyM1
logit diabetes c.age##c.age i.female i.ed4cat
est store nosvyM2
logit diabetes c.age c.age#c.age c.age#c.age#c.age i.female i.ed4cat
est store nosvyM3
}

estimates table nosvyM1 nosvyM2 nosvyM3, ///
    stats(bic aic) keep(c.age##c.age##c.age) ///
        b(%9.5f) p(%9.3f) stfmt(%9.2f)
        
//  3.3 predictions against age

est restore dMage1
mgen, at(age=(50(2.5)100) female=1 ed4cat=2) /// predictions for plot
    atmeans stub(dM1) replace

est restore dMage2
mgen, at(age=(50(2.5)100) female=1 ed4cat=2) /// predictions for plot
    atmeans stub(dM2) replace

est restore dMage3
mgen, at(age=(50(2.5)100) female=1 ed4cat=2) /// predictions for plot
    atmeans stub(dM3) replace

global title     "Women with a high school education"
label var dM1pr1 "M1: age"
label var dM2pr1 "M2: + age-squared"
label var dM3pr1 "M3: + age-cubed"
global ytitled   "ytitle(Pr(diabetes | age,X))"

local graphname "diabetes-prob123"
graph twoway ///
    (connected dM1pr1 dM1age, $M1line) ///
    (connected dM2pr1 dM2age, $M2line) ///
    (connected dM3pr1 dM3age, $M3line), ///
    title("$title", position(11) size(*.8)) ///
    xtitle("Age") xlab(50(10)100) ///
    $ytitled $ylab4 ///
    legend(symxsize(6.9) rows(1) size(*1) region(lcolor(white))) ///    
    $nogapnoline scale(1.1) ///
    caption("`graphname' `tag'", $captionopt) 
graph export `pgm'-`graphname'.$graphfmt, replace

//  3.4 what is the effect of age

estimates restore dMage1
mchange age, amount(delta) delta(10) stats(est p se)                    brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief
                            
estimates restore dMage2
mchange age, amount(delta) delta(10) stats(est p se)                    brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief 
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief 
                            
estimates restore dMage3
mchange age, amount(delta) delta(10) stats(est p se)                    brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief 

//  #3.5 plot effects of age

//  M1

estimates restore dMage1
margins, at(age=gen(age)) at(age=gen(age + 10)) generate(PR1age)
est store temp

gen DC1age = PR1age2 - PR1age1
lab var DC1age "DC for 10 year increase in age"
svy: mean DC1age
local mn = el(r(table),1,1)

est restore temp
mchange age, amount(sd) delta(10) dec(7) // verify restuls

sum DC1age

local graphname dcprob-age-M1dist
histogram DC1age, fcol(red*.7) lcol(red*.7) ///
xtitle(`"{&Delta}Pr/{&Delta}(age{&rarr}age+10)"') ///
scale(1.3) xsize(8) ysize(6.5) plotregion(margin(zero) lcol(white)) ///
xlabel(-.15 -.15 -.10 -.10  `mn' "ADC" .10 .10 .15 .15) ///
    caption("`graphname' `tag'", $captionopt)
graph export `pgm'-`graphname'.$graphfmt, replace

//  M2

estimates restore dMage2
margins, at(age=gen(age)) at(age=gen(age + 10)) generate(PR2age)
est store temp

gen DC2age = PR2age2 - PR2age1
lab var DC2age "DC for 10 year increase in age"
svy: mean DC2age
local mn = el(r(table),1,1)

est restore temp
mchange age, amount(sd) delta(10) dec(7) // verify restuls

sum DC2age

local graphname dcprob-age-M2dist
histogram DC2age, fcol(blue*.7) lcol(blue*.7) ///
xtitle(`"{&Delta}Pr/{&Delta}(age{&rarr}age+10)"') ///
scale(1.3) xsize(8) ysize(6.5) plotregion(margin(zero) lcol(white)) ///
xlabel(-.15 -.15 -.10 -.10  `mn' "ADC" .10 .10 .15 .15) ///
    caption("`graphname' `tag'", $captionopt)
graph export `pgm'-`graphname'.$graphfmt, replace

//  ==========================================================================
//  #4 arthritis

//  #3.1 fit models

svy: logit arthritis c.age i.female i.ed4cat, or
est store aMage1
test age

svy: logit arthritis c.age##c.age i.female i.ed4cat, or
est store aMage2
test c.age#c.age
test age c.age#c.age

svy: logit arthritis c.age c.age#c.age c.age#c.age#c.age i.female i.ed4cat
est store aMage3
test c.age#c.age#c.age
test c.age#c.age c.age#c.age#c.age
test age c.age#c.age c.age#c.age#c.age

estimates table aMage1 aMage2 aMage3, title(arthritis) ///
    eform b(%9.5f) p(%9.3f) 
    
//  #4.2 Fit without survey estimation in order to compare BICs & AICs

qui {
logit arthritis age i.female i.ed4cat
est store nosvyM1
logit arthritis c.age##c.age i.female i.ed4cat
est store nosvyM2
logit arthritis c.age c.age#c.age c.age#c.age#c.age i.female i.ed4cat
est store nosvyM3
}

estimates table nosvyM1 nosvyM2 nosvyM3, ///
    stats(bic aic) keep(c.age##c.age##c.age) ///
    b(%9.5f) p(%9.3f) stfmt(%9.2f)

//  #3.3 predictions against age

est restore aMage1
mgen, at(age=(50(2.5)100) female=1 ed4cat=2) /// predictions for plot
    atmeans stub(aM1) replace

est restore aMage2
mgen, at(age=(50(2.5)100) female=1 ed4cat=2) /// predictions for plot
    atmeans stub(aM2) replace

est restore aMage3
mgen, at(age=(50(2.5)100) female=1 ed4cat=2) /// predictions for plot
    atmeans stub(aM3) replace

global title     "Women with a high school education"
label var aM1pr1 "M1: age"
label var aM2pr1 "M2: + age-squared"
label var aM3pr1 "M3: + age-cubed"
global ytitlea   "ytitle(Pr(arthritis | age,X))"

local graphname "arthritis-prob123"
graph twoway ///
    (connected aM1pr1 aM1age, $M1line) ///
    (connected aM2pr1 aM2age, $M2line) ///
    (connected aM3pr1 aM3age, $M3line), ///
    title("$title", position(11) size(*.8)) ///
    xtitle("Age") xlab(50(10)100) ///
    $ytitled $ylab ///
    legend(symxsize(6.9) rows(1) size(*1) region(lcolor(white))) ///    
    $nogapnoline scale(1.1) ///
    caption("`graphname' `tag'", $captionopt) 
graph export `pgm'-`graphname'.$graphfmt, replace

//  3.4 predictions with CI separately for M2 and M3

local graphname "arthritis-prob2CI"
graph twoway ///
    (rarea aM2ul aM2ll1 aM1age, color(gs13) lw(none)) /// shaded CI
    (connected aM2pr1 aM1age, $M2line ) , ///
    title("Model 2: age + age-squared", position(11) size(*.8)) ///
    xtitle("Age") xlab(50(10)100) ///
    $ytitlea  $ylab  yline(0 1, lcol(black)) ///
    legend(off) $nogapnoline scale(1.1) ///
    caption("`graphname' `tag'", $captionopt) 
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "arthritis-prob3CI"
graph twoway ///
    (rarea aM3ul aM3ll1 aM1age, color(gs13) lw(none)) /// shaded CI
    (connected aM3pr1 aM1age, $M3line ) , ///
    title("Model 3: age + age-squared + age-cubed", position(11) size(*.8)) ///
    xtitle("Age") xlab(50(10)100) ///
    $ytitlea  $ylab  yline(0 1, lcol(black)) ///
    legend(off) $nogapnoline scale(1.1) ///
    caption("`graphname' `tag'", $captionopt) 
graph export `pgm'-`graphname'.$graphfmt, replace

//  #3.4 what is the effect of age

estimates restore aMage1
mchange age, amount(delta) delta(10) stats(est p se)                    brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief
                            
estimates restore aMage2
mchange age, amount(delta) delta(10) stats(est p se)                    brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief 
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief 
                            
estimates restore aMage3
mchange age, amount(delta) delta(10) stats(est p se)                    brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief 

//  #3.5 gender differences at 65

estimates restore aMage1
mchange female if ed4cat==2 & age>=60 & age<=70, brief

estimates restore aMage2
mchange female if ed4cat==2 & age>=60 & age<=70, brief

estimates restore aMage3
mchange female if ed4cat==2 & age>=60 & age<=70, brief

log close
exit

//  TABLES for lecture


capture mat drop dDCage
estimates restore dMage1
mchange age, amount(delta) delta(10) stats(est p se)                    brief
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief
    matrix dDCage = nullmat(dDCage) \ r(table)
                            
estimates restore dMage2
mchange age, amount(delta) delta(10) stats(est p se)                    brief
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief 
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief 
    matrix dDCage = nullmat(dDCage) \ r(table)
                            
estimates restore dMage3
mchange age, amount(delta) delta(10) stats(est p se)                    brief
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
    matrix dDCage = nullmat(dDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief 
    matrix dDCage = nullmat(dDCage) \ r(table)
    
capture mat drop aDCage
estimates restore aMage1
mchange age, amount(delta) delta(10) stats(est p se)                    brief
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief
    matrix aDCage = nullmat(aDCage) \ r(table)
                            
estimates restore aMage2
mchange age, amount(delta) delta(10) stats(est p se)                    brief
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief 
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief 
    matrix aDCage = nullmat(aDCage) \ r(table)
                            
estimates restore aMage3
mchange age, amount(delta) delta(10) stats(est p se)                    brief
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=50) brief
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=70) brief 
    matrix aDCage = nullmat(aDCage) \ r(table)
mchange age, amount(delta) delta(10) stats(est p se) atmeans at(age=90) brief 
    matrix aDCage = nullmat(aDCage) \ r(table)
    
matlist dDCage, format(%9.3f)
matlist aDCage, format(%9.3f)


