capture log close
log using mco18-test-fit-2018-04-04, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  Fitting models, testing regression coefficients, and assessing fit

local pgm mco18-test-fit-2018-04-04
local dte 2018-04-04
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf


//  #1 perfect prediction

use science4, clear
drop if missing(mmale)

gen hipub = pub1>10
label var hipub "Pubs greater than 10?"
label def hipub 0 LoPub 1 HiPub
label val hipub hipub
tabulate mmale hipub, miss row
logit hipub i.mmale phd, nolog


//  #2 Wald tests of single coefficients

use binlfp4, clear

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estimates store logitmodel // store estimates
logit, coeflegend // lists names of coefficients

test k5


//  #3 wald tests of multiple coefficients

//  Ho: wc = hc = 0

test 1.wc 1.hc // not test wc hc
testparm i.wc i.hc // same test

//  Ho: wc = hc

test 1.wc = 1.hc

//  Ho: all agecat = 0

testparm i.agecat

//  Ho: all = 0

test k5 k618 2.agecat 3.agecat 1.wc 1.hc lwg inc
testparm k5 k618 i.agecat i.wc i.hc lwg inc // same test


//  #4 LR tests

//  full model

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc
estimates store full

//  Ho: k5 = 0

logit lfp    k618 i.agecat i.wc i.hc lwg inc, nolog
estimates store dropk5
lrtest full dropk5

//  Ho: wc = hc = 0

logit lfp k5 k618 i.agecat           lwg inc, nolog
estimates store dropwchc
lrtest full dropwchc

//  Ho: all = 0

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc
logit lfp
estimates store constant

* LR-test Formula: 2*[ln(Lu) - ln(Lc)], Lu: full model, Lc: constrained
di 2*(-452.72367 - -514.8732)

lrtest full constant // same result

//  Ho: wc = hc = 0 as difference of chi2

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc
ereturn list // see stored results from dropwchc model
scalar chiall = e(chi2) // store chi2 statistic from model in scalar

logit lfp k5 k618 i.agecat           lwg inc, nolog
scalar chiwchc0 = e(chi2) // store chi2 statistic from model in scalar

di "LR test of hc=wc=0: " chiall-chiwchc0 // LR as a difference of chi-sq test
lrtest full dropwchc // same result


//  #5 Information Criteria

//  m1: base model

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estimates store m1
estat ic // computes IC statistics
qui fitstat, ic save // computes and saves IC statistics

//  m2: adding inc squared and dropping k618 & hc

logit lfp k5      i.agecat i.wc      lwg c.inc##c.inc, nolog
estimates store m2
estat ic
fitstat, ic diff // compares IC statistics from m2 and m1

//  Results indicate strong support for m2.

estimates table m1 m2, stats(N bic) b(%9.3f) t(%6.2f)


//  #6 comparing two models where sample changes

//  m1 base k5 as continuous

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estimates store m1
estat ic
qui fitstat, ic save

//  m2 dummies for k5

logit lfp i.k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estimates store m2
estat ic

//  Due to perfect prediction in m2, 3 cases are dropped and fitstat 
//  complains because IC measures should compare models with the same N. 
//  However, the N's are effectively the same since these cases add 0 to 
//  the ln(L) term. We can force fitstat to make the computations using 
//  the "force" option above results indicate strong support for m1.

fitstat, ic diff force

//  results indicate strong support for m2.

estimates table m1 m2, stats(N bic) b(%9.3f) t(%6.2f)


//  #7 R2 measures

//  adding inc squared and dropping k618 & hc

logit lfp k5 k618 i.agecat i.wc i.hc lwg inc, nolog
estimates store m1
qui fitstat, save // computes fit statistics (including pseudo-R2's)

logit lfp k5      i.agecat i.wc      lwg c.inc##c.inc, nolog
estimates store m2
fitstat, diff

estimates table m1 m2, stats(N bic r2_p) b(%9.3f) t(%6.2f)

//  count R2

estimates restore m1
predict phat  // compute predicted probability for each case

//  compute count R2 using predictins

gen yhat = phat>.5 // generate yhat=1 if predicted prob (phat) is > 0.5
lab var yhat "Predicted y"
tab lfp yhat
di ((178+331)-428) / (753-428) // see formula for adjusted count R2

log close
exit

