capture log close
log using mco18-cme-predictors-blm-2018-04-10, replace text
version 15.1
// version 14.2 // 15.1 is a bit faster...
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  CME: Comparing Marginal Effects Across Models
//  Variable choice: Comparing effets of alterantive predictors

//  This program takes a long time to complete!

local pgm mco18-cme-predictors-blm-2018-04-10
local dte 2018-04-10
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

//  ===============================================================
//  #1 Data management

use gss7216, clear

//  Create Binary Version of DV

gen samesexB = samesexop
lab var samesexB "Views Same-Sex Relationships as Wrong"
recode  samesexB 1/3=1 4=0 5=.
lab def sslab 0 Acceptable 1 Wrong
lab val samesexB sslab

rename sexorient sexident
label var sexident "Sexual Identity"

//  drop all missing cases

foreach var in samesexB sexident sexbehav college woman race age year {
    drop if `var' >= .
}

tab samesexop samesexB, missing

//  Compare two sexual orientation measures    

tab sexident sexbehav, miss

//  # Descriptive statistics

sum i.sexbehav i.woman i.college c.age i.race i.year

codebook samesexB woman college age race year, compact

codebook sexbehav sexident, compact

//  ===============================================================
//  #2 Simultaneous Estimation with GSEM

//  Clone DV to allow gsem to estimate multiple models on same outcome

clonevar samesexBEHAV = samesexB
clonevar samesexIDENT = samesexB

gsem (samesexBEHAV <- i.sexbehav i.woman i.college c.age ///
                      i.race i.year, logit) ///
     (samesexIDENT <- i.sexident i.woman i.college c.age ///
                      i.race i.year, logit), ///
     vce(robust)
        
est store gsemmodel

//  ===============================================================
//  #3 Plot Pr(Wrong) by sexual orientation for both measures

est restore gsemmodel
margins, predict(outcome(samesexBEHAV)) at(sexbehav=(1 2 3)) post
est store probbehav

est restore gsemmodel
margins, predict(outcome(samesexIDENT)) at(sexident=(1 2 3)) post
est store probident

local labopt "labsize(*1.1) glwidth(*1.4) glcolor(black*.7)"

local graphname "cme-predictors-bargraph"
coefplot (probident, color(red)) (probbehav, color(blue)), ///
    vertical recast(bar) barw(0.3) ///
    ciopts(recast(rcap) color(gs8)) citop ///
    legend(order(1 "Identity" 3 "Behavior")) ///  region(lcolor(white))
    xlab(1 "Heterosexual" 2 "Bisexual" 3 "Gay/Lesbian", noticks) ///
    ytitle("Pr(Same-Sex Relationships Wrong)",size(*.85)) ///
    ylab(0(0.1).6, `labopt') ///
    scale(1.3) /// larger text
    xscale(noline) plotregion(style(none)) // turn off x axis line
graph export `pgm'-`graphname'.$graphfmt, replace

//  ===============================================================
//  #4 Probabilities and Marginal Effects by Predictor

//  #4a predicted probabilities and differences for each measure

est restore gsemmodel    
margins, at(sexident=(1 2 3)) at(sexbehav=(1 2 3)) post
qui {
mlincom 7,   rowname("Hetero: Ident")           stat(est se p) clear 
mlincom 4,   rowname("Hetero: Behav")           stat(est se p) add
mlincom 4-7, rowname("Hetero: Difference")      stat(est se p) add
mlincom 8,   rowname("Bisexual: Ident")         stat(est se p) add
mlincom 5,   rowname("Bisexual: Behav")         stat(est se p) add
mlincom 5-8, rowname("Bisexual: Difference")    stat(est se p) add
mlincom 9,   rowname("Gay: Ident")              stat(est se p) add
mlincom 6,   rowname("Gay: Behav")              stat(est se p) add
mlincom 6-9, rowname("Gay: Difference")         stat(est se p) add
}
mlincom, twidth(20) title("Differences in Probabilities Across Models")

//  #4b Pairwise comparison AMEs

est restore gsemmodel    
margins, dydx(sexident sexbehav) post        
qui {
mlincom 3,   rowname("Het vs Bi: Ident")        stat(est se p) clear
mlincom 1,   rowname("Het vs Bi: Behav")        stat(est se p) add
mlincom 1-3, rowname("Het vs Bi: Difference")   stat(est se p) add
mlincom 4,   rowname("Het vs Gay: Ident")       stat(est se p) add
mlincom 2,   rowname("Het vs Gay: Behav")       stat(est se p) add
mlincom 2-4, rowname("Het vs Gay: Difference")  stat(est se p) add
mlincom 1-2, rowname("Bi vs Gay: Ident")        stat(est se p) add
mlincom 3-4, rowname("Bi vs Gay: Behav")        stat(est se p) add
mlincom (3-4)-(1-2), rowname("Bi vs Gay: Difference") stat(est se p) add
}        
mlincom, twidth(20) ///
    title("AMEs for Sexual Orientation Within and Across Models")

log close
exit

