capture log close
log using mco18-orm-ordwarm-2018-04-10, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  Ordinal models for attitudes toward working mothers

local pgm mco18-orm-ordwarm-2018-04-10
local dte 2018-04-10
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

//  #1+ models

use ordwarm4, clear

//  #12 descriptive statistics

tab warm, miss
codebook warm yr89 male white age ed prst, compact

//  #13 compare ologit and oprobit

ologit warm i.yr89 i.male i.white age ed prst, nolog
estimates store olm

oprobit warm i.yr89 i.male i.white age ed prst, nolog
estimates store opm

estimates table olm opm, stats(N chi2 bic) t(%6.2f) b(%8.3f)

//  #14 lrm, olm and standardized coefficients

regress warm i.yr89 i.male i.white age ed prst
listcoef, help

estimates restore olm
listcoef, help std

//  #15 olm and opm with std coefs

estimates restore olm
listcoef, help

estimates restore opm
listcoef, help

//  #2+ OLM predictions

estimates restore olm

//  #21 olm predicted probabilities

predict OLMpr1sd OLMpr2d OLMpr3a OLMpr4sa
label var OLMpr1sd "Pr(1SD|X)"
label var OLMpr2d  "Pr(2D|X)"
label var OLMpr3a  "Pr(3A|X)"
label var OLMpr4sa "Pr(4SA|X)"

//  #22 descriptive statistics for predictions

sum OLMpr1sd OLMpr2d OLMpr3a OLMpr4sa

//  #23 dotplot of predictions

local graphname "olm-predict-dotplot"
dotplot OLMpr1 OLMpr2 OLMpr3 OLMpr4, ylabel(0(.25)1, grid gmin gmax) ///
    title(Model: ologit warm yr89 male white age ed prst, position(11)) ///
    ytitle(Predicted probabilities at observed values) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace
graph export `pgm'-`graphname'.png, width(1600) replace

//  #3+ OLM table of probabilities

//  #30 logit

estimates restore olm

//  #31 probabilities by gender and year at global means

mtable, at(yr89=(0 1) male=(0 1)) atmeans clear
mtable, dydx(male) at(yr89=(0 1)) atvars(1.yr89) atmeans //  1.male

mchange male, at(yr89=0) atmeans brief
mchange male, at(yr89=1) atmeans brief

//  #32 probabilities by gender and year at global means

* predictions for 1977 by gender
mtable, at(yr89=0 male=1) atmeans rowname(Men) clear roweqnm(1977)
mtable, at(yr89=0 male=0) atmeans rowname(Women) below roweqnm(1977)
mtable, dydx(male) at(yr89=0) atmeans rowname(Men-Women) below roweqnm(1977)

* predictions for 1989 by gender
mtable, at(yr89=1 male=1) atmeans rowname(Men) below roweqnm(1989)
mtable, at(yr89=1 male=0) atmeans rowname(Women) below roweqnm(1989)
mtable, dydx(male) at(yr89=1) atmeans rowname(Men_Women) below roweqnm(1989)

* discrete changes for 1977-1989 by gender
mtable, dydx(yr89) at(male=1) atmeans rowname(77to89) below roweqnm(Men)
mtable, dydx(yr89) at(male=0) atmeans rowname(77to89) below roweqnm(Women)

//  #33 probabilities by gender and year at local means

* means by year and gender
sort yr89 male
by yr89 male: sum white age ed prst

* table of predictions
mtable if yr89==0 & male==1, atmeans rowname(Men)   clear roweqnm(1977) 
mtable if yr89==0 & male==0, atmeans rowname(Women) below roweqnm(1977) 
mtable if yr89==1 & male==1, atmeans rowname(Men)   below roweqnm(1989) 
mtable if yr89==1 & male==0, atmeans rowname(Women) below roweqnm(1989) 

* using over
mtable, atmeans over(yr89 male)

//  #4+ marginal effects

estimates restore olm

//  #44 AME vs MEM in ologit; AME in ologit vs mlogit

global warmcol "blue blue*.7 red*.7 red" // graph options

* AME in ologit
mchange, amount(one sd)
local graphname "ame-ologit"
mchangeplot, min(-.15) max(.15) gap(.05) varlabels sig(.05) ///
    mcol($warmcol) aspect(.8) leftmargin(.5) /// leftmargin(1) 
    symbols(D d a A) title(AME for OLM, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "ame-ologit-1st3"
mchangeplot yr89 male white, min(-.15) max(.15) gap(.05) varlabels sig(.05) ///
    mcol($warmcol) aspect(.8) leftmargin(.5) /// leftmargin(1) 
    symbols(D d a A) title(AME for OLM, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "ame-ologit-2nd3"
mchangeplot age ed prst, min(-.15) max(.15) gap(.05) varlabels sig(.05) ///
    mcol($warmcol) aspect(.8) leftmargin(.5) /// leftmargin(1) 
    symbols(D d a A) title(AME for OLM, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  effects of being male and of year of survey

estimates restore olm

margins, dydx(male)
local graphname "ame-male"
marginsplot, recast(bar) ciopts(color(gs5)) ///
    xlab(0.5 " " ///
            1 `""Strongly" "Disagree""' ///
            2 "Disagree" ///
            3 "Agree" ///
            4 `""Strongly" "Agree""' ///
            4.5 " ") ///
    yline(0) plotopts(barw(0.7) color(blue*.8)) ///
    ylab(-.15(.05).15, format(%4.2f) grid gmin gmax)  ///
    xtitle("Working mothers can be good mothers") /// 
    ytitle("ADC comparing men to women") scale(1.2) title("")

graph export `pgm'-`graphname'.$graphfmt, replace

estimates restore olm

margins, dydx(yr89)
local graphname "ame-year"
marginsplot, recast(bar) ciopts(color(gs5)) ///
    xlab(0.5 " " ///
            1 `""Strongly" "Disagree""' ///
            2 "Disagree" ///
            3 "Agree" ///
            4 `""Strongly" "Agree""' ///
            4.5 " ") ///
    yline(0) plotopts(barw(0.7) color(green*.8)) ///
    ylab(-.15(.05).15, format(%4.2f) grid gmin gmax)  ///
    xtitle("Working mothers can be good mothers") /// 
    ytitle("ADC comparing 1977 to 1989") scale(1.2) title("")
graph export `pgm'-`graphname'.$graphfmt, replace
    

* MEM in ologit
mchange, atmeans amount(one sd)
local graphname "mem-ologit"
mchangeplot, min(-.15) max(.15) gap(.05) varlabels sig(.05) ///
    mcol($warmcol) aspect(.8) leftmargin(.5) ///
    symbols(D d a A) title(MEM for OLM, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

* AME in mlogit
mlogit warm i.yr89 i.male i.white age ed prst, nolog
estimates store nrm
mchange, amount(one sd)
local graphname "ame-mlogit"
mchangeplot, min(-.15) max(.15) gap(.05) varlabels sig(.05) ///
    mcol($warmcol) aspect(.8) leftmargin(.5) ///
    symbols(D d a A) title(AME for MNLM, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "ame-mlogit-1st3"
mchangeplot yr89 male white, min(-.15) max(.15) gap(.05) varlabels sig(.05) ///
    mcol($warmcol) aspect(.8) leftmargin(.5) /// leftmargin(1) 
    symbols(D d a A) title(AME for OLM, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "ame-mlogit-2nd3"
mchangeplot age ed prst, min(-.15) max(.15) gap(.05) varlabels sig(.05) ///
    mcol($warmcol) aspect(.8) leftmargin(.5) /// leftmargin(1) 
    symbols(D d a A) title(AME for OLM, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #45 2nd difference

estimate restore olm
mtable, dydx(male) at(yr89=0) rowname(DCmale_77) clear
mtable, dydx(male) at(yr89=1) rowname(DCmale_89) below

* margins for all outcome
estimate restore olm

margins, at(yr89=(0 1) male=(0 1)) post
margins, coeflegend

lincom (_b[1bn._predict#1bn._at]-_b[1bn._predict#2._at]) ///
     - (_b[1bn._predict#3._at]-_b[1bn._predict#4._at])

mlincom (1-2)-(3-4), rowname(SD) stats(est p) clear
mlincom (5-6)-(7-8), rowname(D) stats(est p) add
mlincom (9-10)-(11-12), rowname(A) stats(est p) add
mlincom (13-14)-(15-16), rowname(SA) stats(est p) add

//  #5+ plot probabilities

estimates restore olm

//  #51 compute predictions for women in 1989

mgen, at(age=(20(5)80) male=0 yr89=1) atmeans stub(W89)
codebook W89*, compact

//  #52 predicted probabilities

label var W89pr1 "SD"
label var W89pr2 "D"
label var W89pr3 "A"
label var W89pr4 "SA"
label var W89Cpr1 "SD"
label var W89Cpr2 "SD or D"
label var W89Cpr3 "SD, D or A"

global warmsym "mcol(red red*.9 green*.9 green) "
global warmsym "$warmsym msym(s sh Oh O) msiz(3.5 3.5 3 3)"

//  #53 probability plot

local graphname "prob-byage-w89-global"
graph twoway connected W89pr1 W89pr2 W89pr3 W89pr4 W89age, $warmsym ///
    title(Women in 1989, pos(11))  ///
    subtitle("SA indicates support for working women", pos(11)) ///
    xtitle("Age") xlabel(20(10)80) ///
    ytitle("Probability") ylabel(0(.25).50, grid gmin gmax) ///
    plotregion(margin(zero) lcol(white)) legend(rows(1)) scale(*1.1) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10)) 

graph export `pgm'-`graphname'.$graphfmt, replace

//  #54 cumulative probability plot

local graphname "probcum-byage-w89-global"
graph twoway connected W89Cpr1 W89Cpr2 W89Cpr3 W89age, ///
    $warmsym ///
    title(Women in 1989, pos(11)) $warmsym ///
    subtitle("SA indicates support for working women", pos(11)) ///
    xtitle("Age") xlabel(20(10)80) ///
    ylabel(0(.25)1, grid gmin gmax) yline(1, lcol(black) lwid(*.7)) ///
    ytitle("Cumulative probability") ///  xline(44.93)
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10)) ///
    plotregion(margin(zero) lcol(white)) scale(*1.1)

graph export `pgm'-`graphname'.$graphfmt, replace

//  #55 cumulative probability plot with labels

local graphname "probcum-byage-w89-global-labels"
graph twoway connected W89Cpr1 W89Cpr2 W89Cpr3 W89age, $warmsym ///
    title(Women in 1989, pos(11)) $warmsym ///
    subtitle("SA indicates support for working women", pos(11)) ///
    xtitle("Age") xlabel(20(10)80) yline(1, lcol(black) lwid(*.7)) ///
    ytitle("Cumulative probability") ylabel(0(.25)1, grid gmin gmax) ///
    text(.035 65 "Strongly disagree",place(e)) ///
    text(.21 54 "Disagree",place(e)) ///
    text(.45 40 "Agree",place(e)) ///
    text(.90 25 "Strongly agree",place(e)) legend(off) ///  xline(44.93)
     plotregion(margin(zero) lcol(white)) scale(*1.1) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10)) 

graph export `pgm'-`graphname'.$graphfmt, replace

//  #56 values being plotted

* round results to improve output
foreach v in W89pr1 W89Cpr1 W89pr2 W89Cpr2 W89pr3 W89Cpr3 W89pr4 W89Cpr4 {
    qui replace `v' = round(`v',.001)
}

* verify rounding
list W89age W89pr1 W89Cpr1 W89pr2 W89Cpr2 W89pr3 W89Cpr3 ///
     W89pr4 W89Cpr4 in 1/14, clean

//  #57 building the plot

* clone p* and s* variables
clonevar p1 = W89pr1
clonevar p2 = W89pr2
clonevar p3 = W89pr3
clonevar p4 = W89pr4
clonevar s1 = W89Cpr1
clonevar s2 = W89Cpr2
clonevar s3 = W89Cpr3
replace W89pr2 = .
replace W89pr3 = .
replace W89pr4 = .
replace W89Cpr2 = .
replace W89Cpr3 = .

local graphname "prob-byage-w89-step1"
graph twoway connected W89pr1 W89pr2 W89pr3 W89pr4 W89age, ///
    $warmsym ///
     title(Women in 1989, pos(11))  ///
     subtitle("SA indicates support for working women", pos(11)) ///
     xtitle("Age") xlabel(20(10)80) ylabel(0(.25)1, grid gmin gmax) ///
     xline(44.93) ytitle("Probability") xsize(4) ysize(4)
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "probcum-byage-w89-step1"
graph twoway connected W89Cpr1 W89Cpr2 W89Cpr3 W89age, ///
    $warmsym ///
    title(Women in 1989, pos(11)) $warmsym ///
    subtitle("SA indicates support for working women", pos(11)) ///
    xtitle("Age") xlabel(20(10)80) ylabel(0(.25)1, grid gmin gmax) ///
    xline(44.93) ytitle("Cumulative probability") xsize(4) ysize(4) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

replace W89pr2 = p2
replace W89pr3 = .
replace W89pr4 = .
replace W89Cpr2 = s2
replace W89Cpr3 = .

local graphname "prob-byage-w89-step2"
graph twoway connected W89pr1 W89pr2 W89pr3 W89pr4 W89age, ///
    $warmsym ///
     title(Women in 1989, pos(11))  ///
     subtitle("SA indicates support for working women", pos(11)) ///
     xtitle("Age") xlabel(20(10)80) ///
     ylabel(0(.25)1, grid gmin gmax) ///
     xline(44.93) ytitle("Probability") xsize(4) ysize(4) ///
     caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "probcum-byage-w89-step2"
graph twoway connected W89Cpr1 W89Cpr2 W89Cpr3 W89age, ///
    $warmsym ///
    title(Women in 1989, pos(11)) $warmsym ///
    subtitle("SA indicates support for working women", pos(11)) ///
    xtitle("Age") xlabel(20(10)80) ylabel(0(.25)1, grid gmin gmax) ///
    xline(44.93) ytitle("Cumulative probability") xsize(4) ysize(4) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

replace W89pr2 = p2
replace W89pr3 = p3
replace W89pr4 = .
replace W89Cpr2 = s2
replace W89Cpr3 = s3

local graphname "prob-byage-w89-step3"
graph twoway connected W89pr1 W89pr2 W89pr3 W89pr4 W89age, ///
    $warmsym ///
     title(Women in 1989, pos(11))  ///
     subtitle("SA indicates support for working women", pos(11)) ///
     xtitle("Age") xlabel(20(10)80) ylabel(0(.25)1, grid gmin gmax) ///
     xline(44.93) ytitle("Probability") xsize(4) ysize(4) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "probcum-byage-w89-step3"
graph twoway connected W89Cpr1 W89Cpr2 W89Cpr3 W89age, ///
    $warmsym ///
    title(Women in 1989, pos(11)) $warmsym ///
    subtitle("SA indicates support for working women", pos(11)) ///
    xtitle("Age") xlabel(20(10)80) ylabel(0(.25)1, grid gmin gmax) ///
    xline(44.93) ytitle("Cumulative probability") xsize(4) ysize(4) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

replace W89pr2 = p2
replace W89pr3 = p3
replace W89pr4 = p4
replace W89Cpr2 = s2
replace W89Cpr3 = s3

local graphname "prob-byage-w89-step4"
graph twoway connected W89pr1 W89pr2 W89pr3 W89pr4 W89age, ///
    $warmsym ///
     title(Women in 1989, pos(11))  ///
     subtitle("SA indicates support for working women", pos(11)) ///
     xtitle("Age") xlabel(20(10)80) ylabel(0(.25)1, grid gmin gmax) ///
     xline(44.93) ytitle("Probability") xsize(4) ysize(4) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

local graphname "probcum-byage-w89-step4"
graph twoway connected W89Cpr1 W89Cpr2 W89Cpr3 W89age, ///
    $warmsym ///
    title(Women in 1989, pos(11)) $warmsym ///
    subtitle("SA indicates support for working women", pos(11)) ///
    xtitle("Age") xlabel(20(10)80) ylabel(0(.25)1, grid gmin gmax) ///
    xline(44.93) ytitle("Cumulative probability") xsize(4) ysize(4) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  6+ parallel regressions

//  #62 informally assess parallel regression assumption

estimates restore olm
listcoef, help

* binary logit on 1=SD, 0=D&A&SA
qui logit warmlt2 yr89 male white age ed prst, nolog
estimates store lt2
listcoef

* binary logit on 1=SD&D, 0=A&SA
qui logit warmlt3 yr89 male white age ed prst, nolog
estimates store lt3
listcoef

* binary logit on 1=SD&D&A, 0=SA
qui logit warmlt4 yr89 male white age ed prst, nolog
estimates store lt4
listcoef

//  #63 brant test of parallel regression

estimate restore olm
brant, detail

//  #64 LR test with gologit2

ssc install gologit2 //  install package
gologit2 warm yr89 male white age ed prst, nolog
est store gologit2
lrtest olm gologit2, force //  force since not estimated with same command

log close
exit

DROPPED

//  #24 scatterplot  of predictions

local graphname "olm-predict-scatter"
graph matrix OLMpr1sd OLMpr2d OLMpr3a OLMpr4sa, ///
    msym(smcircle_hollow) xsize(7) ysize(7) ///
    maxes( ylabel(0(.2).6) xlabel(0(.2).6) ) ///
    title(ologit warm yr89 male white age ed prst, position(11)) ///
    subtitle(Predicted probabilities at observed values, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #25 listing predictions

sort OLMpr1sd
list OLMpr1sd warm yr89 male white age ed prst in  1/8, clean
list OLMpr1sd warm yr89 male white age ed prst in -8/l, clean
sort OLMpr2d
list OLMpr2d  warm yr89 male white age ed prst in  1/8, clean
list OLMpr2d  warm yr89 male white age ed prst in -8/l, clean
sort OLMpr3a
list OLMpr3a  warm yr89 male white age ed prst in  1/8, clean
list OLMpr3a  warm yr89 male white age ed prst in -8/l, clean
sort OLMpr4sa
list OLMpr4sa warm yr89 male white age ed prst in  1/8, clean
list OLMpr4sa warm yr89 male white age ed prst in -8/l, clean

/* required for older verisons of stata
* margins for outcome 1
margins, at(yr89=(0 1) male=(0 1)) predict(outcome(1)) post
lincom (_b[1bn._at]-_b[2._at]) - (_b[3._at]-_b[4._at])
* do the same for all four outcomes using loop and mlincom
mlincom, clear //  remove any prior results
estimate restore olm
foreach o in 1 2 3 4 {
    quietly {
        margins, at(yr89=(0 1) male=(0 1)) predict(outcome(`o')) post
        mlincom (1-2)-(3-4), add rowname(Outcome`o') stats(est p)
        estimate restore olm
    }
}
mlincom
*/

//  #66 comparing predictions

estimates restore olm
predict OLMpr1 OLMpr2 OLMpr3 OLMpr4
label var OLMpr1 "olm Pr(1SD|X)"
label var OLMpr2 "olm Pr(2D|X)"
label var OLMpr3 "olm Pr(3A|X)"
label var OLMpr4 "olm Pr(4SA|X)"

estimates restore nrm
predict NRMpr1 NRMpr2 NRMpr3 NRMpr4
label var NRMpr1 "nrm Pr(1SD|X)"
label var NRMpr2 "nrm Pr(2D|X)"
label var NRMpr3 "nrm Pr(3A|X)"
label var NRMpr4 "nrm Pr(4SA|X)"

* use loop to scatter plot orm against nrm predictions.
foreach j in 1 2 3 4 {
    corr OLMpr`j' NRMpr`j'
    local graphname "66-olmVnrmCat`j'"
    scatter OLMpr`j' NRMpr`j', msym(oh) aspect(1) ///
       xlab(0(.2).6, grid gmin gmax) ylab(0(.2).6, grid gmin gmax)  ///
       caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
       graph export `pgm'-`graphname'.$graphfmt, replace
}
