capture log close
log using mco18-orm-partyid-2018-04-10, replace text
version 14.2
clear all
macro drop _all
set linesize 80
set scheme s1manual

//  Modeling Categorical Outcomes - 2018
//  Party identifcation as an ordinal outcome

local pgm mco18-orm-partyid-2018-04-10
local dte 2018-04-10
local who Scott Long
local tag "`pgm'.do `who' `dte'"

global graphfmt emf 
if "`c(os)'"!="Windows" global graphfmt pdf

//  globals for plots

local yaxis_p  "ytitle(Probability of party affiliation)"
global yaxis_p "`yaxis_p' ylab(0(.1).4, grid) ylin(0 .4, lcol(gs14))"
global partycol "blue blue*.5 green red*.5 red"
global line5_opts ///
    msym(O      Oh      dh          sh          s) ///
    lwid(medium medium  medium      medium      medium) ///
    lpat(solid  dash    shortdash   dash        solid) ///
    mcol(red    orange  black       green       blue) ///
    lcol(red    orange  black       green       blue) ///
    mcol(red    red*.8  black       blue*.8     blue) ///
    lcol(red    red*.8  black       blue*.8     blue)

//  #1+ mnlm on party ====================================================

//  #11 descriptive statistics

use partyid4, clear
tab party, miss
codebook party age income black female educ, compact

//  #12 MNLM

mlogit party age10 income10 i.black i.female i.educ
estimates store mnlm
mlogtest, wald
listcoef, help

//  #13 AME

mchange age10 income10, amount(sd)

local graphname "mchangeplot-ame-mnlm"
mchangeplot age10 income10, min(-.06) max(.06) gap(.02) ///
    symbols(D d i r R) sig(.05) ///
    mcol($partycol) aspect(.3) ///
    title(MNLM: Average discrete change, position(11)) ///
    caption("`graphname' `tag'", size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #14 probability plots for olm and mnlm for age and income

capture drop mnlmage*
capture drop mnlminc*
mgen, atmeans at(age10=(2(.5)8.5)) stub(MNLMage)
mgen, atmeans at(income10=(0(1)10)) stub(MNLMinc)

capture drop PLTincome*
capture drop PLTage*

gen PLTincome10 = MNLMincincome10
label var PLTincome10 "Income in $10,000s"
gen PLTincome = MNLMincincome10*10
label var PLTincome "Income in $1,000s"
gen PLTage10 = MNLMageage10
label var PLTage10 "Age in decades"
gen PLTage = MNLMageage10*10
label var PLTage "Age"

global titlem "MNLM"
label var MNLMagepr1 "Strong Dem"
label var MNLMagepr2 "Democrat"
label var MNLMagepr3 "Independent"
label var MNLMagepr4 "Republican"
label var MNLMagepr5 "Strong Rep"
label var MNLMincpr1 "Strong Dem"
label var MNLMincpr2 "Democrat"
label var MNLMincpr3 "Independent"
label var MNLMincpr4 "Republican"
label var MNLMincpr5 "Strong Rep"
label var MNLMageCpr1 "Strong Dem"
label var MNLMageCpr2 "+ Democrat"
label var MNLMageCpr3 "+ Independent"
label var MNLMageCpr4 "+ Republican"
label var MNLMageCpr5 "+ Strong Rep"
label var MNLMincCpr1 "Strong Dem"
label var MNLMincCpr2 "+ Democrat"
label var MNLMincCpr3 "+ Independent"
label var MNLMincCpr4 "+ Republican"
label var MNLMincCpr5 "+ Strong Rep"

* probability by age
local graphname "ageProb-mnlm"
graph twoway (connected MNLMagepr1 MNLMagepr2 MNLMagepr3 ///
    MNLMagepr4 MNLMagepr5 PLTage, $line5_opts), ///
    title("$titlem", pos(11) size(*1.)) $yaxis_p xlab(20(20)80) ///
    legend(rows(2))  ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

* probability by income
local graphname "incProb-mnlm"
graph twoway (connected MNLMincpr1 MNLMincpr2 MNLMincpr3 ///
    MNLMincpr4 MNLMincpr5 PLTincome, $line5_opts), ///
    title("$titlem", pos(11) size(*1.)) $yaxis_p xlab(0(20)100) ///
    legend(rows(2)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #15 probability plots for olm and mnlm for age and income
//      -- extended range

global yaxis_pEX ///
    "`yaxis_p' ylab(0(.25)1, grid)"
local agemin = -100
local agemax = 150
local agedel = 2.5 // 5 is too rough
local agemin10 = `agemin'*10
local agemax10 = `agemax'*10
local agedel10 = `agedel'*10
local agerange = `agemax10'-`agemin10'
global xaxis_ageEX "xlab(`agemin10'(`agerange')`agemax10')"

global line5_optsEX ///
    msym(O      Oh          dh          sh          s) ///
    lwid(medium medium      medium      medium      medium) ///
    lpat(solid  dash        shortdash   dash        solid) ///
    mcol(red    orange      black       green       blue) ///
    lcol(red    orange      black       green       blue) ///
    mcol(red    red*.8      black       blue*.8     blue) ///
    lcol(red    red*.8      black       blue*.8     blue) ///
    msym(i      i           i           i           i)

global at_age   "age10=(2(.5)8.5)"
global at_ageEX   "age10=(`agemin'(`agedel')`agemax')"
capture drop MNLMage*
mgen, atmeans at($at_ageEX) stub(MNLMage)

capture drop PLTage
capture drop PLTage10

gen PLTage10 = MNLMageage10
label var PLTage10 "Age in decades"
gen PLTage = MNLMageage10*10
label var PLTage "Age"

global titlem "MNLM"
label var MNLMagepr1 "Strong Dem"
label var MNLMagepr2 "Democrat"
label var MNLMagepr3 "Independent"
label var MNLMagepr4 "Republican"
label var MNLMagepr5 "Strong Rep"
label var MNLMageCpr1 "Strong Dem"
label var MNLMageCpr2 "+ Democrat"
label var MNLMageCpr3 "+ Independent"
label var MNLMageCpr4 "+ Republican"
label var MNLMageCpr5 "+ Strong Rep"

* probability by age
local graphname "ageProb-mnlm-EX"
graph twoway (connected MNLMagepr1 MNLMagepr2 MNLMagepr3 ///
    MNLMagepr4 MNLMagepr5 PLTage, $line5_optsEX), ///
    title("$titlem", pos(11) size(*1.)) $yaxis_pEX $xaxis_ageEX ///
    legend(rows(2))  ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #2+ olm on party =====================================================

//  #21 descriptive statistics

use partyid4, clear
datasignature confirm
tab party, miss
codebook party age income black female educ, compact

//  #22 OLM

ologit party age10 income10 i.black i.female i.educ
estimates store olm

listcoef, help
brant

//  #23 AME

mchange age10 income10
local graphname "mchangeplot-ame-olm"
mchangeplot age10 income10, min(-.06) max(.06) gap(.02) ///
    mcol($partycol) aspect(.3) ///
    symbols(D d i r R) sig(.05) ///
    title(OLM: Average discrete change, position(11)) ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #24 plots

mgen, atmeans at(age10=(2(.5)8.5)) stub(OLMage)
mgen, atmeans at(income10=(0(1)10)) stub(OLMinc)

capture drop PLTincome
capture drop PLTage
capture drop PLTincome10
capture drop PLTage10

gen PLTincome10 = OLMincincome10
label var PLTincome10 "Income in $10,000s"
gen PLTincome = OLMincincome10*10
label var PLTincome "Income in $1,000s"
gen PLTage10 = OLMageage10
label var PLTage10 "Age in decades"
gen PLTage = OLMageage10*10
label var PLTage "Age"

local title "OLM"
label var OLMagepr1 "Strong Dem"
label var OLMagepr2 "Democrat"
label var OLMagepr3 "Independent"
label var OLMagepr4 "Republican"
label var OLMagepr5 "Strong Rep"
label var OLMincpr1 "Strong Dem"
label var OLMincpr2 "Democrat"
label var OLMincpr3 "Independent"
label var OLMincpr4 "Republican"
label var OLMincpr5 "Strong Rep"
label var OLMageCpr1 "Strong Dem"
label var OLMageCpr2 "+ Democrat"
label var OLMageCpr3 "+ Independent"
label var OLMageCpr4 "+ Republican"
label var OLMageCpr5 "+ Strong Rep"
label var OLMincCpr1 "Strong Dem"
label var OLMincCpr2 "+ Democrat"
label var OLMincCpr3 "+ Independent"
label var OLMincCpr4 "+ Republican"
label var OLMincCpr5 "+ Strong Rep"

* probability by age
local graphname "ageProb-olm"
graph twoway (connected OLMagepr1 OLMagepr2 OLMagepr3 ///
    OLMagepr4 OLMagepr5 PLTage, $line5_opts), ///
    title("`title'", pos(11) size(*1.)) $yaxis_p xlab(20(20)80) ///
    legend(rows(2))  ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

* probability by income
local graphname "incProb-olm"
graph twoway (connected OLMincpr1 OLMincpr2 OLMincpr3 ///
    OLMincpr4 OLMincpr5 PLTincome, $line5_opts), ///
    title("`title'", pos(11) size(*1.)) $yaxis_p xlab(0(20)100) ///
    legend(rows(2))  ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

//  #15 probability plots for olm for age
//      -- extended range

global yaxis_pEX ///
    "`yaxis_p' ylab(0(.25)1, grid)"
local agemin = -100
local agemax = 150
local agedel = 5
local agemin10 = `agemin'*10
local agemax10 = `agemax'*10
local agedel10 = `agedel'*10
local agerange = `agemax10'-`agemin10'
global xaxis_ageEX "xlab(`agemin10'(`agerange')`agemax10')"

global line5_optsEX msym(O Oh dh sh s) ///
    lwid(medium medium medium medium medium) ///
    lpat(solid dash shortdash dash solid) ///
    mcol(red orange black green blue) ///
    lcol(red orange black green blue) ///
    mcol(red red*.8 black blue*.8 blue) ///
    lcol(red red*.8 black blue*.8 blue) ///
    msym(i i i i i)


global at_age   "age10=(2(.5)8.5)"
global at_ageEX   "age10=(`agemin'(`agedel')`agemax')"
capture drop OLMage*
mgen, atmeans at($at_ageEX) stub(OLMage)

capture drop PLTage
capture drop PLTage10

gen PLTage10 = OLMageage10
label var PLTage10 "Age in decades"
gen PLTage = OLMageage10*10
label var PLTage "Age"

global titlem "OLM"
label var OLMagepr1 "Strong Dem"
label var OLMagepr2 "Democrat"
label var OLMagepr3 "Independent"
label var OLMagepr4 "Republican"
label var OLMagepr5 "Strong Rep"
label var OLMageCpr1 "Strong Dem"
label var OLMageCpr2 "+ Democrat"
label var OLMageCpr3 "+ Independent"
label var OLMageCpr4 "+ Republican"
label var OLMageCpr5 "+ Strong Rep"

* probability by age
local graphname "ageProb-olm-EX"
graph twoway (connected OLMagepr1 OLMagepr2 OLMagepr3 ///
    OLMagepr4 OLMagepr5 PLTage, $line5_optsEX), ///
    title("$titlem", pos(11) size(*1.)) $yaxis_pEX $xaxis_ageEX ///
    legend(rows(2))  ///
    caption("`graphname' `tag'",size(*.5) pos(5) col(gs10))
graph export `pgm'-`graphname'.$graphfmt, replace

log close
exit

